airdropuser

package
v0.14.8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 10, 2024 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the airdropuser type in the database.
	Label = "airdrop_user"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldAddress holds the string denoting the address field in the database.
	FieldAddress = "address"
	// FieldPrivateKey holds the string denoting the private_key field in the database.
	FieldPrivateKey = "private_key"
	// FieldCanClaimAirdrop holds the string denoting the can_claim_airdrop field in the database.
	FieldCanClaimAirdrop = "can_claim_airdrop"
	// FieldLastAirdropClaimTime holds the string denoting the last_airdrop_claim_time field in the database.
	FieldLastAirdropClaimTime = "last_airdrop_claim_time"
	// FieldNextAirdropClaimTime holds the string denoting the next_airdrop_claim_time field in the database.
	FieldNextAirdropClaimTime = "next_airdrop_claim_time"
	// FieldClaimedAmount holds the string denoting the claimed_amount field in the database.
	FieldClaimedAmount = "claimed_amount"
	// FieldScheduledAmount holds the string denoting the scheduled_amount field in the database.
	FieldScheduledAmount = "scheduled_amount"
	// FieldAirdropFailedAttempts holds the string denoting the airdrop_failed_attempts field in the database.
	FieldAirdropFailedAttempts = "airdrop_failed_attempts"
	// Table holds the table name of the airdropuser in the database.
	Table = "airdrop_users"
)

Variables

var (
	// AddressValidator is a validator for the "address" field. It is called by the builders before save.
	AddressValidator func(string) error
	// PrivateKeyValidator is a validator for the "private_key" field. It is called by the builders before save.
	PrivateKeyValidator func(string) error
	// DefaultCanClaimAirdrop holds the default value on creation for the "can_claim_airdrop" field.
	DefaultCanClaimAirdrop int
	// DefaultLastAirdropClaimTime holds the default value on creation for the "last_airdrop_claim_time" field.
	DefaultLastAirdropClaimTime int64
	// DefaultNextAirdropClaimTime holds the default value on creation for the "next_airdrop_claim_time" field.
	DefaultNextAirdropClaimTime int64
	// DefaultClaimedAmount holds the default value on creation for the "claimed_amount" field.
	DefaultClaimedAmount decimal.Decimal
	// DefaultScheduledAmount holds the default value on creation for the "scheduled_amount" field.
	DefaultScheduledAmount decimal.Decimal
	// DefaultAirdropFailedAttempts holds the default value on creation for the "airdrop_failed_attempts" field.
	DefaultAirdropFailedAttempts int
	// AirdropFailedAttemptsValidator is a validator for the "airdrop_failed_attempts" field. It is called by the builders before save.
	AirdropFailedAttemptsValidator func(int) error
)

Columns holds all SQL columns for airdropuser fields.

Functions

func Address

func Address(v string) predicate.AirdropUser

Address applies equality check predicate on the "address" field. It's identical to AddressEQ.

func AddressContains

func AddressContains(v string) predicate.AirdropUser

AddressContains applies the Contains predicate on the "address" field.

func AddressContainsFold

func AddressContainsFold(v string) predicate.AirdropUser

AddressContainsFold applies the ContainsFold predicate on the "address" field.

func AddressEQ

func AddressEQ(v string) predicate.AirdropUser

AddressEQ applies the EQ predicate on the "address" field.

func AddressEqualFold

func AddressEqualFold(v string) predicate.AirdropUser

AddressEqualFold applies the EqualFold predicate on the "address" field.

func AddressGT

func AddressGT(v string) predicate.AirdropUser

AddressGT applies the GT predicate on the "address" field.

func AddressGTE

func AddressGTE(v string) predicate.AirdropUser

AddressGTE applies the GTE predicate on the "address" field.

func AddressHasPrefix

func AddressHasPrefix(v string) predicate.AirdropUser

AddressHasPrefix applies the HasPrefix predicate on the "address" field.

func AddressHasSuffix

func AddressHasSuffix(v string) predicate.AirdropUser

AddressHasSuffix applies the HasSuffix predicate on the "address" field.

func AddressIn

func AddressIn(vs ...string) predicate.AirdropUser

AddressIn applies the In predicate on the "address" field.

func AddressLT

func AddressLT(v string) predicate.AirdropUser

AddressLT applies the LT predicate on the "address" field.

func AddressLTE

func AddressLTE(v string) predicate.AirdropUser

AddressLTE applies the LTE predicate on the "address" field.

func AddressNEQ

func AddressNEQ(v string) predicate.AirdropUser

AddressNEQ applies the NEQ predicate on the "address" field.

func AddressNotIn

func AddressNotIn(vs ...string) predicate.AirdropUser

AddressNotIn applies the NotIn predicate on the "address" field.

func AirdropFailedAttempts

func AirdropFailedAttempts(v int) predicate.AirdropUser

AirdropFailedAttempts applies equality check predicate on the "airdrop_failed_attempts" field. It's identical to AirdropFailedAttemptsEQ.

func AirdropFailedAttemptsEQ

func AirdropFailedAttemptsEQ(v int) predicate.AirdropUser

AirdropFailedAttemptsEQ applies the EQ predicate on the "airdrop_failed_attempts" field.

func AirdropFailedAttemptsGT

func AirdropFailedAttemptsGT(v int) predicate.AirdropUser

AirdropFailedAttemptsGT applies the GT predicate on the "airdrop_failed_attempts" field.

func AirdropFailedAttemptsGTE

func AirdropFailedAttemptsGTE(v int) predicate.AirdropUser

AirdropFailedAttemptsGTE applies the GTE predicate on the "airdrop_failed_attempts" field.

func AirdropFailedAttemptsIn

func AirdropFailedAttemptsIn(vs ...int) predicate.AirdropUser

AirdropFailedAttemptsIn applies the In predicate on the "airdrop_failed_attempts" field.

func AirdropFailedAttemptsLT

func AirdropFailedAttemptsLT(v int) predicate.AirdropUser

AirdropFailedAttemptsLT applies the LT predicate on the "airdrop_failed_attempts" field.

func AirdropFailedAttemptsLTE

func AirdropFailedAttemptsLTE(v int) predicate.AirdropUser

AirdropFailedAttemptsLTE applies the LTE predicate on the "airdrop_failed_attempts" field.

func AirdropFailedAttemptsNEQ

func AirdropFailedAttemptsNEQ(v int) predicate.AirdropUser

AirdropFailedAttemptsNEQ applies the NEQ predicate on the "airdrop_failed_attempts" field.

func AirdropFailedAttemptsNotIn

func AirdropFailedAttemptsNotIn(vs ...int) predicate.AirdropUser

AirdropFailedAttemptsNotIn applies the NotIn predicate on the "airdrop_failed_attempts" field.

func And

func And(predicates ...predicate.AirdropUser) predicate.AirdropUser

And groups predicates with the AND operator between them.

func CanClaimAirdrop

func CanClaimAirdrop(v int) predicate.AirdropUser

CanClaimAirdrop applies equality check predicate on the "can_claim_airdrop" field. It's identical to CanClaimAirdropEQ.

func CanClaimAirdropEQ

func CanClaimAirdropEQ(v int) predicate.AirdropUser

CanClaimAirdropEQ applies the EQ predicate on the "can_claim_airdrop" field.

func CanClaimAirdropGT

func CanClaimAirdropGT(v int) predicate.AirdropUser

CanClaimAirdropGT applies the GT predicate on the "can_claim_airdrop" field.

func CanClaimAirdropGTE

func CanClaimAirdropGTE(v int) predicate.AirdropUser

CanClaimAirdropGTE applies the GTE predicate on the "can_claim_airdrop" field.

func CanClaimAirdropIn

func CanClaimAirdropIn(vs ...int) predicate.AirdropUser

CanClaimAirdropIn applies the In predicate on the "can_claim_airdrop" field.

func CanClaimAirdropLT

func CanClaimAirdropLT(v int) predicate.AirdropUser

CanClaimAirdropLT applies the LT predicate on the "can_claim_airdrop" field.

func CanClaimAirdropLTE

func CanClaimAirdropLTE(v int) predicate.AirdropUser

CanClaimAirdropLTE applies the LTE predicate on the "can_claim_airdrop" field.

func CanClaimAirdropNEQ

func CanClaimAirdropNEQ(v int) predicate.AirdropUser

CanClaimAirdropNEQ applies the NEQ predicate on the "can_claim_airdrop" field.

func CanClaimAirdropNotIn

func CanClaimAirdropNotIn(vs ...int) predicate.AirdropUser

CanClaimAirdropNotIn applies the NotIn predicate on the "can_claim_airdrop" field.

func ClaimedAmount

func ClaimedAmount(v decimal.Decimal) predicate.AirdropUser

ClaimedAmount applies equality check predicate on the "claimed_amount" field. It's identical to ClaimedAmountEQ.

func ClaimedAmountEQ

func ClaimedAmountEQ(v decimal.Decimal) predicate.AirdropUser

ClaimedAmountEQ applies the EQ predicate on the "claimed_amount" field.

func ClaimedAmountGT

func ClaimedAmountGT(v decimal.Decimal) predicate.AirdropUser

ClaimedAmountGT applies the GT predicate on the "claimed_amount" field.

func ClaimedAmountGTE

func ClaimedAmountGTE(v decimal.Decimal) predicate.AirdropUser

ClaimedAmountGTE applies the GTE predicate on the "claimed_amount" field.

func ClaimedAmountIn

func ClaimedAmountIn(vs ...decimal.Decimal) predicate.AirdropUser

ClaimedAmountIn applies the In predicate on the "claimed_amount" field.

func ClaimedAmountLT

func ClaimedAmountLT(v decimal.Decimal) predicate.AirdropUser

ClaimedAmountLT applies the LT predicate on the "claimed_amount" field.

func ClaimedAmountLTE

func ClaimedAmountLTE(v decimal.Decimal) predicate.AirdropUser

ClaimedAmountLTE applies the LTE predicate on the "claimed_amount" field.

func ClaimedAmountNEQ

func ClaimedAmountNEQ(v decimal.Decimal) predicate.AirdropUser

ClaimedAmountNEQ applies the NEQ predicate on the "claimed_amount" field.

func ClaimedAmountNotIn

func ClaimedAmountNotIn(vs ...decimal.Decimal) predicate.AirdropUser

ClaimedAmountNotIn applies the NotIn predicate on the "claimed_amount" field.

func ID

func ID(id uint) predicate.AirdropUser

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id uint) predicate.AirdropUser

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id uint) predicate.AirdropUser

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id uint) predicate.AirdropUser

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...uint) predicate.AirdropUser

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id uint) predicate.AirdropUser

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id uint) predicate.AirdropUser

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id uint) predicate.AirdropUser

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uint) predicate.AirdropUser

IDNotIn applies the NotIn predicate on the ID field.

func LastAirdropClaimTime

func LastAirdropClaimTime(v int64) predicate.AirdropUser

LastAirdropClaimTime applies equality check predicate on the "last_airdrop_claim_time" field. It's identical to LastAirdropClaimTimeEQ.

func LastAirdropClaimTimeEQ

func LastAirdropClaimTimeEQ(v int64) predicate.AirdropUser

LastAirdropClaimTimeEQ applies the EQ predicate on the "last_airdrop_claim_time" field.

func LastAirdropClaimTimeGT

func LastAirdropClaimTimeGT(v int64) predicate.AirdropUser

LastAirdropClaimTimeGT applies the GT predicate on the "last_airdrop_claim_time" field.

func LastAirdropClaimTimeGTE

func LastAirdropClaimTimeGTE(v int64) predicate.AirdropUser

LastAirdropClaimTimeGTE applies the GTE predicate on the "last_airdrop_claim_time" field.

func LastAirdropClaimTimeIn

func LastAirdropClaimTimeIn(vs ...int64) predicate.AirdropUser

LastAirdropClaimTimeIn applies the In predicate on the "last_airdrop_claim_time" field.

func LastAirdropClaimTimeLT

func LastAirdropClaimTimeLT(v int64) predicate.AirdropUser

LastAirdropClaimTimeLT applies the LT predicate on the "last_airdrop_claim_time" field.

func LastAirdropClaimTimeLTE

func LastAirdropClaimTimeLTE(v int64) predicate.AirdropUser

LastAirdropClaimTimeLTE applies the LTE predicate on the "last_airdrop_claim_time" field.

func LastAirdropClaimTimeNEQ

func LastAirdropClaimTimeNEQ(v int64) predicate.AirdropUser

LastAirdropClaimTimeNEQ applies the NEQ predicate on the "last_airdrop_claim_time" field.

func LastAirdropClaimTimeNotIn

func LastAirdropClaimTimeNotIn(vs ...int64) predicate.AirdropUser

LastAirdropClaimTimeNotIn applies the NotIn predicate on the "last_airdrop_claim_time" field.

func NextAirdropClaimTime

func NextAirdropClaimTime(v int64) predicate.AirdropUser

NextAirdropClaimTime applies equality check predicate on the "next_airdrop_claim_time" field. It's identical to NextAirdropClaimTimeEQ.

func NextAirdropClaimTimeEQ

func NextAirdropClaimTimeEQ(v int64) predicate.AirdropUser

NextAirdropClaimTimeEQ applies the EQ predicate on the "next_airdrop_claim_time" field.

func NextAirdropClaimTimeGT

func NextAirdropClaimTimeGT(v int64) predicate.AirdropUser

NextAirdropClaimTimeGT applies the GT predicate on the "next_airdrop_claim_time" field.

func NextAirdropClaimTimeGTE

func NextAirdropClaimTimeGTE(v int64) predicate.AirdropUser

NextAirdropClaimTimeGTE applies the GTE predicate on the "next_airdrop_claim_time" field.

func NextAirdropClaimTimeIn

func NextAirdropClaimTimeIn(vs ...int64) predicate.AirdropUser

NextAirdropClaimTimeIn applies the In predicate on the "next_airdrop_claim_time" field.

func NextAirdropClaimTimeLT

func NextAirdropClaimTimeLT(v int64) predicate.AirdropUser

NextAirdropClaimTimeLT applies the LT predicate on the "next_airdrop_claim_time" field.

func NextAirdropClaimTimeLTE

func NextAirdropClaimTimeLTE(v int64) predicate.AirdropUser

NextAirdropClaimTimeLTE applies the LTE predicate on the "next_airdrop_claim_time" field.

func NextAirdropClaimTimeNEQ

func NextAirdropClaimTimeNEQ(v int64) predicate.AirdropUser

NextAirdropClaimTimeNEQ applies the NEQ predicate on the "next_airdrop_claim_time" field.

func NextAirdropClaimTimeNotIn

func NextAirdropClaimTimeNotIn(vs ...int64) predicate.AirdropUser

NextAirdropClaimTimeNotIn applies the NotIn predicate on the "next_airdrop_claim_time" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.AirdropUser) predicate.AirdropUser

Or groups predicates with the OR operator between them.

func PrivateKey

func PrivateKey(v string) predicate.AirdropUser

PrivateKey applies equality check predicate on the "private_key" field. It's identical to PrivateKeyEQ.

func PrivateKeyContains

func PrivateKeyContains(v string) predicate.AirdropUser

PrivateKeyContains applies the Contains predicate on the "private_key" field.

func PrivateKeyContainsFold

func PrivateKeyContainsFold(v string) predicate.AirdropUser

PrivateKeyContainsFold applies the ContainsFold predicate on the "private_key" field.

func PrivateKeyEQ

func PrivateKeyEQ(v string) predicate.AirdropUser

PrivateKeyEQ applies the EQ predicate on the "private_key" field.

func PrivateKeyEqualFold

func PrivateKeyEqualFold(v string) predicate.AirdropUser

PrivateKeyEqualFold applies the EqualFold predicate on the "private_key" field.

func PrivateKeyGT

func PrivateKeyGT(v string) predicate.AirdropUser

PrivateKeyGT applies the GT predicate on the "private_key" field.

func PrivateKeyGTE

func PrivateKeyGTE(v string) predicate.AirdropUser

PrivateKeyGTE applies the GTE predicate on the "private_key" field.

func PrivateKeyHasPrefix

func PrivateKeyHasPrefix(v string) predicate.AirdropUser

PrivateKeyHasPrefix applies the HasPrefix predicate on the "private_key" field.

func PrivateKeyHasSuffix

func PrivateKeyHasSuffix(v string) predicate.AirdropUser

PrivateKeyHasSuffix applies the HasSuffix predicate on the "private_key" field.

func PrivateKeyIn

func PrivateKeyIn(vs ...string) predicate.AirdropUser

PrivateKeyIn applies the In predicate on the "private_key" field.

func PrivateKeyLT

func PrivateKeyLT(v string) predicate.AirdropUser

PrivateKeyLT applies the LT predicate on the "private_key" field.

func PrivateKeyLTE

func PrivateKeyLTE(v string) predicate.AirdropUser

PrivateKeyLTE applies the LTE predicate on the "private_key" field.

func PrivateKeyNEQ

func PrivateKeyNEQ(v string) predicate.AirdropUser

PrivateKeyNEQ applies the NEQ predicate on the "private_key" field.

func PrivateKeyNotIn

func PrivateKeyNotIn(vs ...string) predicate.AirdropUser

PrivateKeyNotIn applies the NotIn predicate on the "private_key" field.

func ScheduledAmount

func ScheduledAmount(v decimal.Decimal) predicate.AirdropUser

ScheduledAmount applies equality check predicate on the "scheduled_amount" field. It's identical to ScheduledAmountEQ.

func ScheduledAmountEQ

func ScheduledAmountEQ(v decimal.Decimal) predicate.AirdropUser

ScheduledAmountEQ applies the EQ predicate on the "scheduled_amount" field.

func ScheduledAmountGT

func ScheduledAmountGT(v decimal.Decimal) predicate.AirdropUser

ScheduledAmountGT applies the GT predicate on the "scheduled_amount" field.

func ScheduledAmountGTE

func ScheduledAmountGTE(v decimal.Decimal) predicate.AirdropUser

ScheduledAmountGTE applies the GTE predicate on the "scheduled_amount" field.

func ScheduledAmountIn

func ScheduledAmountIn(vs ...decimal.Decimal) predicate.AirdropUser

ScheduledAmountIn applies the In predicate on the "scheduled_amount" field.

func ScheduledAmountLT

func ScheduledAmountLT(v decimal.Decimal) predicate.AirdropUser

ScheduledAmountLT applies the LT predicate on the "scheduled_amount" field.

func ScheduledAmountLTE

func ScheduledAmountLTE(v decimal.Decimal) predicate.AirdropUser

ScheduledAmountLTE applies the LTE predicate on the "scheduled_amount" field.

func ScheduledAmountNEQ

func ScheduledAmountNEQ(v decimal.Decimal) predicate.AirdropUser

ScheduledAmountNEQ applies the NEQ predicate on the "scheduled_amount" field.

func ScheduledAmountNotIn

func ScheduledAmountNotIn(vs ...decimal.Decimal) predicate.AirdropUser

ScheduledAmountNotIn applies the NotIn predicate on the "scheduled_amount" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the AirdropUser queries.

func ByAddress

func ByAddress(opts ...sql.OrderTermOption) OrderOption

ByAddress orders the results by the address field.

func ByAirdropFailedAttempts

func ByAirdropFailedAttempts(opts ...sql.OrderTermOption) OrderOption

ByAirdropFailedAttempts orders the results by the airdrop_failed_attempts field.

func ByCanClaimAirdrop

func ByCanClaimAirdrop(opts ...sql.OrderTermOption) OrderOption

ByCanClaimAirdrop orders the results by the can_claim_airdrop field.

func ByClaimedAmount

func ByClaimedAmount(opts ...sql.OrderTermOption) OrderOption

ByClaimedAmount orders the results by the claimed_amount field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByLastAirdropClaimTime

func ByLastAirdropClaimTime(opts ...sql.OrderTermOption) OrderOption

ByLastAirdropClaimTime orders the results by the last_airdrop_claim_time field.

func ByNextAirdropClaimTime

func ByNextAirdropClaimTime(opts ...sql.OrderTermOption) OrderOption

ByNextAirdropClaimTime orders the results by the next_airdrop_claim_time field.

func ByPrivateKey

func ByPrivateKey(opts ...sql.OrderTermOption) OrderOption

ByPrivateKey orders the results by the private_key field.

func ByScheduledAmount

func ByScheduledAmount(opts ...sql.OrderTermOption) OrderOption

ByScheduledAmount orders the results by the scheduled_amount field.

Jump to